/***************************************************************************
 *		  Copyright (C) 1994  Charles P. Peterson                  *
 *	     4007 Enchanted Sun, San Antonio, Texas 78244-1254             *
 *              Email: Charles_P_Peterson@fcircus.sat.tx.us                *
 *                                                                         *
 *		  This is free software with NO WARRANTY.                  *
 *	      See gfft.c, or run program itself, for details.              *
 *		      Support is available for a fee.                      *
 ***************************************************************************
 *
 * Program:     gfft--General FFT analysis
 * File:        amigadef.h   ** SYSTEM DEPENDENT **
 * Purpose:     system dependent definitions
 * Author:      Charles Peterson (CPP)
 * History:     31-May-1993 CPP; Created.
 *               6-Jul-1994 CPP (0.74); allow simultaneous MORE sessions
 * Comment:     This file should NOT include storage allocations.
 */

#ifndef AMIGADEF_H
#define AMIGADEF_H

/*
 * HELP_PATH_LIST is used for COPYING (Gnu Public License) and help file(s)
 * init files, etc.
 *
 * STARTUP_PATH_LIST is used for finding and reading the startup file
 *
 * "\0" is recognized as the current directory
 * NULL ends the path list
 */

#define HELP_PATH_LIST {"\0","S:",NULL}
#define STARTUP_PATH_LIST {"\0","S:",NULL}

#define HELP_FILE_NAME "gfft.help"
#define TEMP_DATAFILE_NAME "t:temp-%s.fft-%d"
#define TEMP_NAME_PREFIX "t:temp-"

#define PLOT_COMMAND_FILE_NAME "ram:cli.temp-gfft-plot"
#define MORE_COMMAND_FILE_NAME "ram:cli.temp-gfft-more-"
#define GNUPLOT_COMMAND_FILE_NAME "ram:gnuplot.temp-gfft-plot"
#define DELETE_COMMAND_FILE_NAME "ram:cli.temp-gfft-delete-"

#define MAX_PLOT_COMMANDFILE_NAME 64

#define GNUPLOT_STACKSIZE 30000

#define MESSAGE_FILE_NAME "ram:temp-gfft-more-"

#define DATA_FILE_WILDCARD "t:temp-#?.fft-#?"
#define COMMAND_FILE_WILDCARD "ram:cli.temp-gfft-#?"
#define MESSAGE_FILE_WILDCARD "ram:temp-gfft-more-#?"

#define BACKUP_FILE_CHARACTER '_'

#define DEFAULT_INPUT_BINARY TRUE
#define DEFAULT_OUTPUT_BINARY FALSE

#define DEFAULT_INPUT_BITS 8
#define DEFAULT_OUTPUT_BITS 64

#define DEFAULT_INPUT_ZERO 0
#define DEFAULT_OUTPUT_ZERO 0

#define DEFAULT_RATE 0   /* This forces an error unless specified */

#define COMMENT_DELIMITER(ch) \
  (ch == ';' || ch == '#' || ch == '!' || ch == '(')

/*
 * Define ULONG, UWORD, UBYTE, and BOOLEAN undefining first if necessary
 */

#ifdef ULONG
#undef ULONG
#endif
#define ULONG unsigned long

#ifdef UWORD
#undef UWORD
#endif
#define UWORD unsigned short

#ifdef UBYTE
#undef UBYTE
#endif
#define UBYTE unsigned char

#ifdef BOOLEAN
#undef BOOLEAN
#endif
#define BOOLEAN int

/* Four-character IDentifier builder. for 68000 family */
#define MakeID(a,b,c,d)  ((ULONG)(a)<<24L | (ULONG)(b)<<16L | (c)<<8 | (d))

#ifdef NONAG
#undef NONAG
#define NONAG (Key == (key = magic_number(\
"I\'ll tell you how to do this if you just send a note of thanks.")))
#endif

#endif /* ifndef AMIGADEF_H */


